#cs ----------------------------------------------------------------------------

 AutoIt Version: 3.3.5.6 (beta)
 Author:    Niels Wagenaar

 Script Version : 0.1
 Script Function:
    Converts a Dreamboxedit based CSV file to a VDR 1.7.x compatible channels.conf on Windows.
	
	Usage:
	
	- Open your Dreambox settings with Dreamboxedit 3.0.0 and Export Alle Bouquets in Excel Readable Format
	- Open Excel and Import the file DreamBoxEdit Export Bouquets.txt through Data -> From Text
	- Save the file as DreamBoxEdit Export Bouquets.CSV at the same location where the script/executable is located.
	- Run the script or run convert_channels.exe
	- Stop VDR
	- Upload the channels.conf to your VDR
	- Start VDR

#ce ----------------------------------------------------------------------------

; Script Start - Add your code below here


#include <Constants.au3>

; Open Source file.
$fImport = FileOpen("DreamBoxEdit Export Bouquets.csv", 0)

; Check if we were able to open the file.
If $fImport = -1 Then
	ConsoleWrite("Error, unable to open source file" & @CRLF)
    Exit
EndIf

; Open destination file.
$fExport = FileOpen("channels.conf", 2)

; Check if were able to create the destination file.
If $fExport = -1 Then
	ConsoleWrite("Error, unable to open destination file" & @CRLF)
    Exit
EndIf

; Checking the number of lines
$iNumber = 0
While 1
	$sDummy = FileReadLine($fImport)
    If @error Then ExitLoop
	$iNumber = $iNumber +1
WEnd

; Reset the fileposition to the beginning.
FileSetPos($fImport, 0, $FILE_BEGIN)

Global $sFavorite    = ""

While 1
	Local $sChannelData
	
	$sFileImport = FileReadLine($fImport)

	If @error Then ExitLoop
	
    ; Load the line from the file as an array.
	$csv = StringRegExp( $sFileImport,'(".*?";|.*?;|;)',3)

	; Only start the conversion when it's indeed SAT-data
	If ( $csv[0] <> "Bouquetnumber;" ) Then 

		; Check if the bouqet/favorite is allready used, if not write it to channels.conf
		If $sFavorite <> StringStripWS((StringReplace($csv[3], ";", "")),1) Then
			$sFavorite = StringStripWS( (StringReplace($csv[3], ";", "")),1)
			FileWriteLine( $fExport, ":" & 	$sFavorite )
			ConsoleWrite("DEBUG Data - Added Bouquet : " & $sFavorite & @CRLF)
		EndIf

		; Let's retrieve the data from the CSV
		$sChannelName          = $csv[4]  																			; ChannelName
		$sChannelProvider      = StringReplace($csv[5], ";", ":") 													; Provider
		$sChannelFreq          = StringTrimRight($csv[9], 4 ) & ":" 												; Frequency
		$sChannelPolarization  = StringReplace( (StringLower( $csv[11])), ";", "" )                                 ; Polarization
		$sChannelFEC           = "C" & StringStripWS(StringReplace( (StringReplace($csv[12], "/", "")), ";", ""),8) ; FEC

		; DVB-S/DVB-S2 modulation/RollOff settings:
		Switch StringReplace($csv[6], ";", "")
		Case "1" ; QPSK with DVB-S
			$sChannelModulation = "M2"
			$sChannelRolloff    = "O35"
			$sChannelType       = "S0:"
		Case "22" ; 8PSK with DVB-S2
			$sChannelModulation = "M5"
			$sChannelRolloff    = "O0"
			$sChannelType       = "S1:"
		Case "25" ; QPSK with DVB-S2
			$sChannelModulation = "M2"
			$sChannelRolloff    = "O0"
			$sChannelType       = "S1:"
		EndSwitch
		
		; Satellite information
		; Only Hotbird 13.0, Astra 19.2, Astra 23.5, Astra 28.2 and Eurobird 1 supported.
		Switch StringReplace($csv[7], ";", "")
		Case "13"
			$sChannelSatellite   = "S13E:"
		Case "19,2"
			$sChannelSatellite   = "S19.2E:"
		Case "23,5"
			$sChannelSatellite   = "S23.5E:"
		Case "28,2"
			$sChannelSatellite   = "S28.2E:"
		Case "28,5"
			$sChannelSatellite   = "S28.5E:"
		EndSwitch

		$sChannelSymR = StringTrimRight($csv[10], 4 ) & ":" ; Symbolrate
		
		; VPID
		$sChannelVPID = StringReplace($csv[18], ";", "") 	
		If $sChannelVPID == "" Then
			$sChannelVPID = "0" ;
		EndIf

		; PCR
		If $csv[21] == ";" Then
			$sChannelPCR = StringReplace($csv[21], ";", ":")
		Else
			$sChannelPCR = "+" & StringReplace($csv[21], ";", ":")
		EndIf
		
		; APID
		$sChannelAPID =	StringReplace($csv[19], ";", ":")
		If $sChannelAPID == ":" Then
			$sChannelAPID = "0:"
		EndIf
		
		; TPID
		$sChannelTPID = StringReplace($csv[20], ";", ":")
		If $sChannelTPID == ":" Then
			$sChannelTPID = "0:"
		EndIf
			
		$sChannelCAID = "0:" ; CAID is allways FTA, VDR will set it correctly.
		
		; SID
		$sChannelSID  = StringReplace($csv[13], ";", ":")
		If $sChannelSID == ":" Then
			$sChannelSID = "0:"
		EndIf
		
		; NID
		$sChannelNID  = StringReplace($csv[15], ";", ":")
		If $sChannelNID == ":" Then
			$sChannelNID = "0:"
		EndIf
		
		; TID
		$sChannelTID  = StringReplace($csv[14], ";", ":")
		If $sChannelTID == ":" Then
			$sChannelPID = "0:"
		EndIf
		
		; RID
		$sChannelRID  = "0"  ; Allways 0 for DVB-S/DVB-S2?
		
		; Let combine all the retrieved information and make the compatible VDR channel-line.		
		$sChannelData = $sChannelName & $sChannelProvider & $sChannelFreq & $sChannelPolarization & $sChannelFEC & $sChannelModulation & $sChannelRolloff & $sChannelType & $sChannelSatellite 
		$sChannelData = $sChannelData & $sChannelSymR & $sChannelVPID & $sChannelPCR & $sChannelAPID & $sChannelTPID & $sChannelCAID & $sChannelSID & $sChannelNID & $sChannelTID & $sChannelRID
		
		; Write the combined channel.conf information to the file.
		FileWriteLine( $fExport, $sChannelData )
		ConsoleWrite("DEBUG Data - Added Channel : " & $sChannelData & @CRLF)
		
	EndIf

WEnd

; Close all open files.
FileClose($fImport)

; New channels are automaticly added, so make sure it has his own favorite/bouquet.
FileWriteLine( $fExport, ":New Channels" )

; Flush and close channels.conf
FileFlush($fExport)
FileClose($fExport)


